@@ -11,11 +11,14 @@ import re
 
 
 class EvaluationObject:
-    def __init__(self, host, query_rel_dict, index, name):
+    def __init__(self, host, query_rel_dict, index, name, verified_certificates=False):
         self.queries_rels = dict(query_rel_dict)
         self.index = index
         self.name = name
-        self.elasticsearch = Elasticsearch([host], ca_certs=False, verify_certs=False, read_timeout=120)
+        if verified_certificates:
+            self.elasticsearch = Elasticsearch([host])
+        else:
+            self.elasticsearch = Elasticsearch([host], ca_certs=False, verify_certs=verified_certificates, read_timeout=120)
         self.elasticsearch.ping()
         self.true_positives = {}
         self.false_positives = {}
@@ -32,15 +35,15 @@ class EvaluationObject:
 
         Parameters
         ----------
-        k: int
+        :arg k: int
             ranking size
-        size: int or None
+        :arg size: int or None
             search size, if size is None, it will set Elastisearch default value
 
-        Returns
+        :Returns:
         -------
 
-        size: int
+        :size: int
             adjusted search size
 
         """
@@ -55,16 +58,16 @@ class EvaluationObject:
 
         Parameters
         ----------
-        query_id: int
+        :arg query_id: int
             current query id
-        size: int
+        :arg size: int
             search size
-        fields: list of strings
+        :arg fields: list of strings
             fields that should be searched on
 
-        Returns
+        :Returns:
         -------
-        result: nested dict
+        :result: nested dict
             search result from Elasticsearch
 
         """
@@ -78,14 +81,14 @@ class EvaluationObject:
 
         Parameters
         ----------
-        query: str
+        :arg query: str
             query to search on
-        size: int
+        :arg size: int
             searched size
-        fields: list of str
+        :arg fields: list of str
             fields, that should be searched
 
-        Returns
+        :Returns:
         -------
         search body for highlighting the matched results
 
@@ -112,11 +115,11 @@ class EvaluationObject:
 
         Parameters
         ----------
-        query_ids: list, int or None
+        :arg query_ids: list, int or None
 
-        Returns
+        :Returns:
         -------
-        query_ids: list
+        :query_ids: list
             transformed query ids
 
         """
@@ -132,16 +135,16 @@ class EvaluationObject:
 
         Parameters
         ----------
-        pos: int or str,
+        :arg pos: int or str,
             ranking position
-        hit: nested dict
+        :arg hit: nested dict
             hit found in Elasticsearch
-        fields: list of strings
+        :arg fields: list of strings
             fields so analyze
 
-        Returns
+        :Returns:
         -------
-        variable: nested dict
+        :variable: nested dict
             structured hit
 
         """
@@ -173,13 +176,13 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             query ids; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             number of results that should be returned and ranked
 
         Returns
@@ -200,12 +203,12 @@ class EvaluationObject:
 
         Parameters
         ----------
-        tp: int
+        :arg tp: int
             true positives
-        fn: int
+        :arg fn: int
             false negatives
 
-        Returns
+        :Returns:
         -------
         Recall value
 
@@ -225,12 +228,12 @@ class EvaluationObject:
 
         Parameters
         ----------
-        tp: int
+        :arg tp: int
             true positives
-        fp: int
+        :arg fp: int
             false positives
 
-        Returns
+        :Returns:
         -------
         Precision value
 
@@ -250,14 +253,14 @@ class EvaluationObject:
 
         Parameters
         ----------
-        precision: int
+        :arg precision: int
             precision value
-        recall: int
+        :arg recall: int
             recall value
-        factor: int or float
+        :arg factor: int or float
             1 is the default to calculate F1-Score, but you can also choose another factor
 
-        Returns
+        :Returns:
         -------
         F-Score value
 
@@ -278,21 +281,21 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             query ids; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             top results that should be returned from Elasticsearch
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it returns json
 
-        Returns
+        :Returns:
         -------
 
-        true positives: json
+        :true positives: json
 
         """
         size = self._check_size(k, size)
@@ -321,21 +324,21 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             query ids; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             top results that should be returned from Elasticsearch
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it returns json
 
-        Returns
+        :Returns:
         -------
 
-        false positives: json
+        :false positives: json
 
         """
         size = self._check_size(k, size)
@@ -365,21 +368,21 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             query ids; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             top results that should be returned from Elasticsearch
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it returns json
 
-        Returns
+        :Returns:
         -------
 
-        false negatives: json
+        :false negatives: json
 
         """
         size = self._check_size(k, size)
@@ -426,18 +429,18 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             searched queries; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             top results that should be returned from Elasticsearch
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it saves to object variable
 
-        Returns
+        :Returns:
         -------
 
         json with Recall values
@@ -467,18 +470,18 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             searched queries; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             top results that should be returned from Elasticsearch
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it saves to object variable
 
-        Returns
+        :Returns:
         -------
 
         json with Precision values
@@ -508,20 +511,20 @@ class EvaluationObject:
 
         Parameters
         ----------
-        searched_queries: int or list or None
+        :arg searched_queries: int or list or None
             searched queries; if None it searches with all queries
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        size: int
+        :arg size: int
             search size
-        k: int
+        :arg k: int
             top results that should be returned from Elasticsearch
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it saves to object variable
-        factor: int
+        :arg factor: int
             can be used to weight the F score, default is 1
 
-        Returns
+        :Returns:
         -------
 
         json with F-score values
@@ -550,20 +553,19 @@ class EvaluationObject:
 
         Parameters
         ----------
-        distribution: string
+        :arg distribution: string
             'true_positives', 'false_positives' or 'false_negatives'
-        distribution_json: json
+        :arg distribution_json: json
             json with all the distributions needed; e.g. EvaluationObject.true_positives
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False it returns json
-        k: int
+        :arg k: int
             size of k top search results
 
-        Returns
-        -------
-
-        sorted_counts: json
-            counted distribution per query, as a sum and as a percentage
+        :Returns:
+        ---------
+            :sorted_counts: json
+                    counted distribution per query, as a sum and as a percentage
 
         """
         if isinstance(distribution_json, str):
@@ -617,16 +619,16 @@ class EvaluationObject:
 
         Parameters
         ----------
-        query_id: int
+        :arg query_id: int
             id of query that should be explained
-        doc_id: int
+        :arg doc_id: int
             id of document that should be explained
-        fields: list of str
+        :arg fields: list of str
             fields that should be searched on
-        dumps: True or False
+        :arg dumps: True or False
             True by default, if False it won't convert dict to json
 
-        Returns
+        :Returns:
         -------
 
         json or dict explaining query and document match
@@ -683,10 +685,11 @@ class ComparisonTool:
     def __init__(self, host, qry_rel_dict, eval_obj_1=None, eval_obj_2=None,
                  fields=['text', 'title'], index_1=None, index_2=None, name_1='approach_1',
                  name_2='approach_2', size=20, k=20):
+        self.qrys_rels = qry_rel_dict
         if eval_obj_1 is None:
-            eval_obj_1 = EvaluationObject(host, qry_rel_dict, index_1, name_1)
+            eval_obj_1 = EvaluationObject(host, self.qrys_rels, index_1, name_1)
         if eval_obj_2 is None:
-            eval_obj_1 = EvaluationObject(host, qry_rel_dict, index_2, name_2)
+            eval_obj_1 = EvaluationObject(host, self.qrys_rels, index_2, name_2)
         self.eval_obj_1 = eval_obj_1
         self.eval_obj_2 = eval_obj_2
         self.eval_obj_1.get_fscore(None, fields, size, k)
@@ -703,14 +706,14 @@ class ComparisonTool:
 
         Parameters
         ----------
-        queries: int or list
+        :arg queries: int or list
             query ids
-        eval_objs: list
+        :arg eval_objs: list
             EvaluationObjs that should be compared
-        conditions: list
+        :arg conditions: list
             conditions that should be printed
 
-        Returns
+        :Returns:
         -------
         pandas data frame
 
@@ -730,14 +733,14 @@ class ComparisonTool:
 
         Parameters
         ----------
-        queries: int or list
+        :arg queries: int or list
             query ids
-        eval_objs: list
+        :arg eval_objs: list
             EvaluationObjs that should be compared
-        distributions: list
+        :arg distributions: list
             distributions that should be printed
 
-        Returns
+        :Returns:
         -------
         pandas data frame
 
@@ -757,16 +760,16 @@ class ComparisonTool:
 
         Parameters
         ----------
-        query_id: int
+        :arg query_id: int
             query id of query that should be explained
-        doc_id: int
+        :arg doc_id: int
             id of document that should be explained
-        fields: list
+        :arg fields: list
             fields that should be searched
-        eval_objs: list
+        :arg eval_objs: list
             EvaluationObjs that should be compared
 
-        Returns
+        :Returns:
         -------
         pandas data frame
 
@@ -794,19 +797,21 @@ class ComparisonTool:
         #           explain_dict[eval_objs[0].name]['Group'] = group_counter
         return pd.DataFrame(data=explain_dict).sort_values(by=['Terms'])
 
-    def _get_csv_terms(self, query_id, doc_id, fields, eval_objs):
+    def _get_csv_terms(self, query_id, doc_id, fields, decimal_separator, eval_objs):
         """
         Returns dict containing all the found terms and their scores.
 
         Parameters
         ----------
-        query_id: int
+        :arg query_id: int
             query id of query that should be explained
-        doc_id: int
+        :arg doc_id: int
             id of document that should be explained
-        fields: list
+        :arg fields: list
             fields that should be searched
-        eval_objs: list
+        :arg decimal_separator: string
+            choose a decimal separator; by default it's a comma, but for english you might prefer a dot
+        :arg eval_objs: list
             EvaluationObjs that should be compared
 
         Returns
@@ -819,7 +824,7 @@ class ComparisonTool:
             for field in fields:
                 for function in explain[field]['details']:
                     term_dict[obj.name][field+': '+(self._extract_terms(function["function"]["description"]))] = str(
-                        function["function"]["value"]).replace('.', ',')
+                        function["function"]["value"]).replace('.', decimal_separator)
         extra_1 = set(term_dict[eval_objs[0].name]) - set(term_dict[eval_objs[1].name])
         for key in extra_1:
             term_dict[eval_objs[1].name][key] = 0
@@ -843,12 +848,12 @@ class ComparisonTool:
 
         Parameters
         ----------
-        string: str
+        :arg string: str
             string of all the matched terms
 
-        Returns
+        :Returns:
         -------
-        terms: list of str
+        :terms: list of str
             extracted terms
 
         """
@@ -863,12 +868,12 @@ class ComparisonTool:
 
         Parameters
         ----------
-        condition: string
+        :arg condition: string
             "fscore", "precision" or "recall"
-        dumps: True or False
+        :arg dumps: True or False
             if True it returns json.dumps, if False saves to object variable
 
-        Returns
+        :Returns:
         -------
         json with value differences
 
@@ -900,15 +905,15 @@ class ComparisonTool:
 
         Parameters
         ----------
-        distribution: str
+        :arg distribution: str
             distribution to return; possible arguments are 'false_positives' and 'false_negatives'
-        highest: True or False
+        :arg highest: True or False
             if True it only returns the set with the highest count of disjoints
 
-        Returns
+        :Returns:
         -------
 
-        ordered_results: OrderedDict
+        :ordered_results: OrderedDict
             disjoint lists for each approach in a dictionary for each query regarding the distribution
 
         """
@@ -942,18 +947,18 @@ class ComparisonTool:
 
     def get_specific_comparison(self, query_id, doc_id, fields=['text', 'title']):
         """
-        Function to get position, highlights and scores for a specific query and a specific document in comparison.
+        Function to get position, highlights and scores for a specific query and a specific query in comparison.
 
         Parameters
         ----------
-        query_id
-        doc_id: int
+        :arg query_id
+        :arg doc_id: int
             doc id that should be looked at
-        fields: list
+        :arg fields: list
             list of fields that should be searched on
-        Returns
+        :Returns:
         -------
-        json.dumps(comp_dict): dict dumped as json
+        :json.dumps(comp_dict): dict dumped as json
             filled with comparison for given query and doc id
         """
         comp_dict = defaultdict()
@@ -991,18 +996,18 @@ class ComparisonTool:
 
         Parameters
         ----------
-        queries: int or list or None
+        :arg queries: int or list or None
             if None it searches with all queries
-        eval_objs: list
+        :arg eval_objs: list
             EvaluationObjs; if None it uses the ones already implemented in the ComparisonTool object
-        distributions: list
+        :arg distributions: list
             distributions that should be printed; by default tp, fp and fn are used
-        download: True or False
+        :arg download: True or False
             saves the plot as svg; by default False which leads to not saving the visualization
-        path_to_file: string
+        :arg path_to_file: string
             path and filename the visualization should be saved to, e.g. './myfolder/save_this.svg'
 
-        Prints
+        :Prints:
         -------
 
         visualization via matplot as plt.show()
@@ -1034,18 +1039,18 @@ class ComparisonTool:
 
         Parameters
         ----------
-        queries: int or list or None
+        :arg queries: int or list or None
             if None it searches with all queries
-        eval_objs: list
+        :arg eval_objs: list
             EvaluationObjs; if None it uses the ones already implemented in the ComparisonTool object
-        conditions: list
+        :arg conditions: list
             conditions that should be printed; by default precision, recall and f1-score are used
-        download: True or False
+        :arg download: True or False
             saves the plot as svg; by default False which leads to not saving the visualization
-        path_to_file: string
+        :arg path_to_file: string
             path and filename the visualization should be saved to, e.g. './myfolder/save_this.svg'
 
-        Prints
+        :Prints:
         -------
 
         visualization via matplot as plt.show()
@@ -1072,26 +1077,26 @@ class ComparisonTool:
         plt.show()
 
     def visualize_explanation(self, query_id, doc_id, fields=['text', 'title'], eval_objs=None, download=False,
-                              path_to_file='./save_vis_explanation.svg'):
+                              path_to_file='./save_vis_explaination.svg'):
         """
         Visualize in comparison which words were better scored using approach, specific query and a specific document.
 
         Parameters
         ----------
-        queries: int or list or None
+        :arg queries: int or list or None
             if None it searches with all queries
-        doc_id: int
+        :arg doc_id: int
             id of document that should be explained
-        fields: list
+        :arg fields: list
             fields that should be searched, by default 'text' and 'title' are searched
-        eval_objs: list
+        :arg eval_objs: list
             EvaluationObjs; if None it uses the ones already implemented in the ComparisonTool object
-        download: True or False
+        :arg download: True or False
             saves the plot as svg; by default False which leads to not saving the visualization
-        path_to_file: string
+        :arg path_to_file: string
             path and filename the visualization should be saved to, e.g. './myfolder/save_this.svg'
 
-        Prints
+        :Prints:
         -------
 
         visualization via matplot as plt.show()
@@ -1110,40 +1115,33 @@ class ComparisonTool:
             plt.savefig(path_to_file, format="svg")
         plt.show()
 
-    def visualize_explanation_csv(self, query_id, doc_id, path_to_save_to, fields=['text', 'title'], eval_objs=None):
+    def visualize_explanation_csv(self, query_id, doc_id, path_to_save_to, fields=['text', 'title'], decimal_separator=',', eval_objs=None):
         """
         Saves explanation table to csv
 
         Parameters
         ----------
-        query_id: int
+        :arg query_id: int
             query id of query that should be explained
-        doc_id: int
+        :arg doc_id: int
             id of document that should be explained
-        path_to_save_to: string
+        :arg path_to_save_to: string
             path and filename the visualization should be saved to, e.g. './myfolder/save_that.csv'
-        fields: list
+        :arg fields: list
             fields that should be searched, by default 'text' and 'title' are searched
-        eval_objs: list or None
+        :arg decimal_separator: string
+            choose a decimal separator; by default it's a comma, but for english you might prefer a dot
+        :arg eval_objs: list or None
             exactly two EvaluationObjs; if None it uses the ones from the ComparisonTool
 
-        Returns
+        :Returns:
         -------
         csv file to feed it to program to create graphs, e.g. Google Sheets or Microsoft Excel
 
-        """
-        """
-
-        :param query_id
-        :param doc_id
-        :param path_to_save_to
-        :param fields
-        :param eval_objs
-        :return:
         """
         if not eval_objs:
             eval_objs = [self.eval_obj_1, self.eval_obj_2]
-        panda_explain = self._get_csv_terms(query_id, doc_id, fields, eval_objs)
+        panda_explain = self._get_csv_terms(query_id, doc_id, fields, decimal_separator, eval_objs)
         keys = sorted(panda_explain.keys())
         with open(path_to_save_to, "w") as outfile:
             writer = csv.writer(outfile, delimiter=";")
